"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * A class top arse incoing parameters and populate a list of request fields e.g. id and field types e.g. query
 * whose value must later be parsed as a JSON object, JSON Exploded Object, JSON Array, or JSON Exploded Array
 */
class ParametersTransform {
    constructor(parseResult, schema) {
        this.parameters = parseResult;
        this.schema = schema;
    }
    applyExplodedJsonTransform(req) {
        // forcing convert to object if scheme describes param as object + explode
        // for easy validation, keep the schema but update whereabouts of its sub components
        this.parameters.parseObjectExplode.forEach(item => {
            if (req[item.reqField]) {
                // check if there is at least one of the nested properties before create the parent
                const atLeastOne = item.properties.some(p => req[item.reqField].hasOwnProperty(p));
                if (atLeastOne) {
                    req[item.reqField][item.name] = {};
                    item.properties.forEach(property => {
                        var _a, _b;
                        if (req[item.reqField][property]) {
                            const type = (_b = (_a = this.schema.properties[item.reqField].properties[item.name].properties) === null || _a === void 0 ? void 0 : _a[property]) === null || _b === void 0 ? void 0 : _b.type;
                            const value = req[item.reqField][property];
                            const coercedValue = type === 'array' && !Array.isArray(value) ? [value] : value;
                            req[item.reqField][item.name][property] = coercedValue;
                            delete req[item.reqField][property];
                        }
                    });
                }
            }
        });
    }
    applyJsonTransform(req) {
        /**
         * support json in request params, query, headers and cookies
         * like this filter={"type":"t-shirt","color":"blue"}
         *
         * https://swagger.io/docs/specification/describing-parameters/#schema-vs-content
         */
        this.parameters.parseJson.forEach(item => {
            var _a;
            if ((_a = req[item.reqField]) === null || _a === void 0 ? void 0 : _a[item.name]) {
                try {
                    req[item.reqField][item.name] = JSON.parse(req[item.reqField][item.name]);
                }
                catch (e) {
                    // NOOP If parsing failed but _should_ contain JSON, validator will catch it.
                    // May contain falsely flagged parameter (e.g. input was object OR string)
                }
            }
        });
    }
    applyJsonArrayTransform(req) {
        /**
         * array deserialization
         * filter=foo,bar,baz
         * filter=foo|bar|baz
         * filter=foo%20bar%20baz
         */
        this.parameters.parseArray.forEach(item => {
            var _a;
            if ((_a = req[item.reqField]) === null || _a === void 0 ? void 0 : _a[item.name]) {
                req[item.reqField][item.name] = req[item.reqField][item.name].split(item.delimiter);
            }
        });
    }
    applyExplodedJsonArrayTransform(req) {
        /**
         * forcing convert to array if scheme describes param as array + explode
         */
        this.parameters.parseArrayExplode.forEach(item => {
            var _a;
            if (((_a = req[item.reqField]) === null || _a === void 0 ? void 0 : _a[item.name]) &&
                !(req[item.reqField][item.name] instanceof Array)) {
                req[item.reqField][item.name] = [req[item.reqField][item.name]];
            }
        });
    }
    applyPathTransform(req) {
        var _a;
        const openapi = req.openapi;
        const shouldUpdatePathParams = Object.keys(openapi.pathParams).length > 0;
        if (shouldUpdatePathParams) {
            req.params = (_a = openapi.pathParams, (_a !== null && _a !== void 0 ? _a : req.params));
        }
    }
}
exports.ParametersTransform = ParametersTransform;
//# sourceMappingURL=parameters.transform.js.map